@@ -8,9 +8,16 @@ import oommfc.scripts
 from .compute import compute
 from .delete import delete
 from .drivers import Driver, HysteresisDriver, MinDriver, TimeDriver
-from .evolvers import (CGEvolver, EulerEvolver, RungeKuttaEvolver,
-                       SpinTEvolver, SpinXferEvolver, UHH_ThetaEvolver,
-                       Xf_ThermHeunEvolver, Xf_ThermSpinXferEvolver)
+from .evolvers import (
+    CGEvolver,
+    EulerEvolver,
+    RungeKuttaEvolver,
+    SpinTEvolver,
+    SpinXferEvolver,
+    UHH_ThetaEvolver,
+    Xf_ThermHeunEvolver,
+    Xf_ThermSpinXferEvolver,
+)
 
 __version__ = pkg_resources.get_distribution(__name__).version
 
@@ -50,8 +57,9 @@ def test():
     >>> # md.test()
 
     """
-    return pytest.main(['-m', 'not travis and not docker',
-                        '-v', '--pyargs', 'oommfc', '-l'])  # pragma: no cover
+    return pytest.main(
+        ["-m", "not travis and not docker", "-v", "--pyargs", "oommfc", "-l"]
+    )  # pragma: no cover
 
 
 def test_docker():
@@ -66,5 +74,6 @@ def test_docker():
     >>> # md.test_docker()
 
     """
-    return pytest.main(['-m', 'docker', '-v',
-                        '--pyargs', 'oommfc', '-l'])  # pragma: no cover
+    return pytest.main(
+        ["-m", "docker", "-v", "--pyargs", "oommfc", "-l"]
+    )  # pragma: no cover
