@@ -34,32 +34,39 @@ class TimeDriver(Driver):
     [...]
 
     """
-    _allowed_attributes = ['evolver',
-                           'stopping_dm_dt',
-                           'stage_iteration_limit',
-                           'total_iteration_limit',
-                           'stage_count_check',
-                           'checkpoint_file',
-                           'checkpoint_interval',
-                           'checkpoint_disposal',
-                           'start_iteration',
-                           'start_stage',
-                           'start_stage_iteration',
-                           'start_stage_start_time',
-                           'start_stage_elapsed_time',
-                           'start_last_timestep',
-                           'normalize_aveM_output',
-                           'report_max_spin_angle',
-                           'report_wall_time']
+
+    _allowed_attributes = [
+        "evolver",
+        "stopping_dm_dt",
+        "stage_iteration_limit",
+        "total_iteration_limit",
+        "stage_count_check",
+        "checkpoint_file",
+        "checkpoint_interval",
+        "checkpoint_disposal",
+        "start_iteration",
+        "start_stage",
+        "start_stage_iteration",
+        "start_stage_start_time",
+        "start_stage_elapsed_time",
+        "start_last_timestep",
+        "normalize_aveM_output",
+        "report_max_spin_angle",
+        "report_wall_time",
+    ]
 
     def _checkargs(self, **kwargs):
-        t, n = kwargs['t'], kwargs['n']
+        t, n = kwargs["t"], kwargs["n"]
         if t <= 0:
-            msg = f'Cannot drive with {t=}.'
+            msg = f"Cannot drive with {t=}."
             raise ValueError(msg)
         if not isinstance(n, int):
-            msg = f'Cannot drive with {type(n)=}.'
+            msg = f"Cannot drive with {type(n)=}."
             raise ValueError(msg)
         if n <= 0:
-            msg = f'Cannot drive with {n=}.'
+            msg = f"Cannot drive with {n=}."
             raise ValueError(msg)
+
+    @property
+    def _x(self):
+        return "t"
