@@ -1,10 +1,12 @@
 import abc
-import datetime
+import contextlib
 import logging
 import os
+import pathlib
 import shutil
 import subprocess as sp
 import sys
+import tempfile
 import time
 
 import micromagneticmodel as mm
@@ -12,10 +14,10 @@ import ubermagutil as uu
 
 import oommfc as oc
 
-log = logging.getLogger('oommfc')
+log = logging.getLogger("oommfc")
 
 
-class OOMMFRunner(metaclass=abc.ABCMeta):
+class OOMMFRunner(mm.ExternalRunner):
     """Abstract class for running OOMMF."""
 
     def __del__(self):
@@ -26,99 +28,20 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
         work without killing.
 
         """
-        if sys.platform != 'win32':
+        if sys.platform != "win32":
             self._kill()
 
-    def call(self, argstr, need_stderr=False, n_threads=None, verbose=1):
-        """Call OOMMF by passing ``argstr`` to OOMMF.
+    @property
+    def package_name(self):
+        """Simulation package name."""
+        return "OOMMF"
 
-        Parameters
-        ----------
-        argstr : str
-
-            Argument string passed to OOMMF.
-
-        need_stderr : bool, optional
-
-            If ``need_stderr=True``, standard error is captured. Defaults to
-            ``False``.
-
-        verbose : int, optional
-
-            If ``verbose=0``, no output is printed. For ``verbose>=1``
-            information about the OOMMF runner and the runtime is printed to
-            stdout. Defaults is ``verbose=1``.
-
-        Raises
-        ------
-        RuntimeError
-
-            If an error occured.
-
-        Returns
-        -------
-        int
-
-            When the OOMMF run was successful, ``0`` is returned.
-
-        Examples
-        --------
-        1. Getting OOMMF runner automatically and calling it.
-
-        >>> import oommfc as oc
-        ...
-        >>> runner = oc.runner.runner
-        >>> runner.call(argstr='+version')
-        Running OOMMF...
-        CompletedProcess(...)
-
-        """
-        if verbose >= 1:
-            now = datetime.datetime.now()
-            timestamp = '{}/{:02d}/{:02d} {:02d}:{:02d}'.format(now.year,
-                                                                now.month,
-                                                                now.day,
-                                                                now.hour,
-                                                                now.minute)
-            print((f'Running OOMMF ({self.__class__.__name__})'
-                   f'[{timestamp}]... '),
-                  end='')
-            tic = time.time()
-
-        res = self._call(argstr=argstr, need_stderr=need_stderr,
-                         n_threads=n_threads)
-        if sys.platform == 'win32':
-            self._kill()  # required for oc.delete; oommf keeps file ownership
-        if verbose >= 1:
-            toc = time.time()
-            seconds = '({:0.1f} s)'.format(toc - tic)
-            print(seconds)  # append seconds to the previous print.
-
-        if res.returncode != 0:
-            if sys.platform != 'win32':
-                # Only on Linux and MacOS - on Windows we do not get stderr and
-                # stdout.
-                stderr = res.stderr.decode('utf-8', 'replace')
-                stdout = res.stdout.decode('utf-8', 'replace')
-                cmdstr = ' '.join(res.args)
-                print('OOMMF error:')
-                print(f'\tcommand: {cmdstr}')
-                print(f'\tstdout: {stdout}')
-                print(f'\tstderr: {stderr}')
-                print('\n')
-            raise RuntimeError('Error in OOMMF run.')
-
-        return res
+    def _call(self, argstr, need_stderr=False, n_threads=None, dry_run=False):
+        """This method should be implemented in subclass."""
 
     @abc.abstractmethod
-    def _call(self, argstr, need_stderr=False, n_threads=None):
-        """This method should be implemented in subclass."""
-        pass  # pragma: no cover
-
-    @abc.abstractmethod
-    def _kill(self, targets=('all',)):
-        """This method should be implemented in subclass."""
-        pass  # pragma: no cover
+    def _kill(self, targets=("all",)):
+        """Kill OOMMF."""
 
     @abc.abstractmethod
     def errors(self):
@@ -151,12 +74,11 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
         ...
         >>> runner = oc.runner.runner
         >>> runner.version
-        Running OOMMF...
         '...'
 
         """
-        res = self.call(argstr='+version', need_stderr=True)
-        return res.stderr.decode('utf-8').split('OOMMF')[-1].strip()
+        res = self.call(argstr="+version", need_stderr=True, verbose=0)
+        return res.stderr.decode("utf-8").split("OOMMF")[-1].strip()
 
     @property
     def platform(self):
@@ -176,13 +98,12 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
         ...
         >>> runner = oc.runner.runner
         >>> runner.platform
-        Running OOMMF...
         '...'
 
         """
         # in 2.0a3 platform information is written to stdout
-        res = self.call(argstr='+platform', need_stderr=True)
-        return res.stdout.decode('utf-8')
+        res = self.call(argstr="+platform", need_stderr=True, verbose=0)
+        return res.stdout.decode("utf-8")
 
     @property
     def status(self):
@@ -211,10 +132,10 @@ class OOMMFRunner(metaclass=abc.ABCMeta):
         try:
             td = oc.TimeDriver()
             td.drive(system, t=1e-12, n=1, runner=self)
-            print('OOMMF found and running.')
+            print("OOMMF found and running.")
             return 0
         except (EnvironmentError, RuntimeError):
-            print('Cannot find OOMMF.')
+            print("Cannot find OOMMF.")
             return 1
 
     @abc.abstractmethod
@@ -234,30 +155,42 @@ class NativeOOMMFRunner(OOMMFRunner):
     def __init__(self):
         # oommf launchhost gets stuck on Windows
         # -> it is not possible to run multiple calculations in parallel
-        if sys.platform != 'win32':
-            launchhost = sp.run([*self.oommf, 'launchhost', '0'],
-                                stdout=sp.PIPE)
-            port = launchhost.stdout.decode('utf-8', 'replace').strip('\n')
+        if sys.platform != "win32":
+            launchhost = sp.run([*self.oommf, "launchhost", "0"], stdout=sp.PIPE)
+            port = launchhost.stdout.decode("utf-8", "replace").strip("\n")
             self.env = dict(OOMMF_HOSTPORT=port, **os.environ)
         else:
             self.env = os.environ
 
-    def _call(self, argstr, need_stderr=False, n_threads=None):
-        cmd = [*self.oommf, 'boxsi', '+fg', argstr, '-exitondone', '1']
+    def _call(self, argstr, need_stderr=False, n_threads=None, dry_run=False):
+        cmd = [*self.oommf, "boxsi", "+fg", argstr, "-exitondone", "1"]
 
         # Not clear why we cannot get stderr and stdout on win32. Calls to
         # OOMMF get stuck.
         stdout = stderr = sp.PIPE
-        if sys.platform == 'win32' and not need_stderr:
+        if sys.platform == "win32" and not need_stderr:
             stdout = stderr = None  # pragma: no cover
 
         if n_threads is not None:
-            cmd += ['-threads', str(n_threads)]
+            cmd += ["-threads", str(n_threads)]
 
-        return sp.run(cmd, stdout=stdout, stderr=stderr, env=self.env)
+        if dry_run:
+            return cmd
+        else:
+            with self._kill_oommf_on_windows():
+                return sp.run(cmd, stdout=stdout, stderr=stderr, env=self.env)
 
-    def _kill(self, targets=('all',)):
-        sp.run([*self.oommf, 'killoommf', '-q'] + list(targets), env=self.env)
+    @contextlib.contextmanager
+    def _kill_oommf_on_windows(self, targets=("all",)):
+        """Required for oc.delete; oommf keeps file ownership."""
+        try:
+            yield
+        finally:
+            if sys.platform == "win32":
+                self._kill()
+
+    def _kill(self, targets=("all",)):
+        sp.run([*self.oommf, "killoommf", "-q"] + list(targets), env=self.env)
 
 
 @uu.inherit_docs
@@ -274,19 +207,18 @@ class TclOOMMFRunner(NativeOOMMFRunner):
 
     def __init__(self, oommf_tcl):
         self.oommf_tcl = oommf_tcl  # a path to oommf.tcl
-        self.oommf = ['tclsh', self.oommf_tcl]
+        self.oommf = ["tclsh", self.oommf_tcl]
         super().__init__()
 
     def errors(self):
-        errors_file = os.path.join(os.path.dirname(self.oommf_tcl),
-                                   'boxsi.errors')
-        with open(errors_file, 'r') as f:
+        errors_file = os.path.join(os.path.dirname(self.oommf_tcl), "boxsi.errors")
+        with open(errors_file, "r") as f:
             errors = f.read()
 
         return errors
 
     def __repr__(self):
-        return f'TclOOMMFRunner({self.oommf_tcl})'
+        return f"TclOOMMFRunner({self.oommf_tcl})"
 
 
 @uu.inherit_docs
@@ -301,7 +233,7 @@ class ExeOOMMFRunner(NativeOOMMFRunner):
 
     """
 
-    def __init__(self, oommf_exe='oommf'):
+    def __init__(self, oommf_exe="oommf"):
         self.oommf_exe = shutil.which(oommf_exe)
         self.oommf = [self.oommf_exe]
         super().__init__()
@@ -310,17 +242,21 @@ class ExeOOMMFRunner(NativeOOMMFRunner):
         try:
             errors_file = os.path.join(
                 os.path.dirname(shutil.which(self.oommf_exe)),
-                '..', 'opt', 'oommf', 'boxsi.errors')
-            with open(errors_file, 'r') as f:
+                "..",
+                "opt",
+                "oommf",
+                "boxsi.errors",
+            )
+            with open(errors_file, "r") as f:
                 errors = f.read()
             return errors
 
         except FileNotFoundError:
-            msg = 'boxsi.errors cannot be retrieved.'
+            msg = "boxsi.errors cannot be retrieved."
             raise EnvironmentError(msg)
 
     def __repr__(self):
-        return f'ExeOOMMFRunner({self.oommf_exe})'
+        return f"ExeOOMMFRunner({self.oommf_exe})"
 
 
 @uu.inherit_docs
@@ -337,32 +273,50 @@ class DockerOOMMFRunner(OOMMFRunner):
 
         Docker image on DockerHub. Defaults to ``oommf/oommf:20a3``.
 
+    selinux : bool, optional
+
+        If ``True`` use additional ``:z`` flag for the mounted directories. This can be
+        required to get read/write access when using SELinux. Use with caution and check
+        the Docker documentation on SELinux:
+        https://docs.docker.com/storage/bind-mounts/#configure-the-selinux-label.
+        Alternatively, you can set SELinux to Permissive Mode to get read/write access.
+        Defaults to ``False``.
+
     """
 
-    def __init__(self, docker_exe='docker', image='oommf/oommf:20a3'):
+    def __init__(self, docker_exe="docker", image="oommf/oommf:20a3", selinux=False):
         self.docker_exe = docker_exe
         self.image = image
+        self.selinux = selinux
 
-    def _call(self, argstr, need_stderr=False, n_threads=None):
-        cmd = [self.docker_exe, 'run', '-v', os.getcwd()+':/io',
-               self.image, '/bin/bash', '-c',
-               ('tclsh /usr/local/oommf/oommf/oommf.tcl boxsi '
-                '+fg {} -exitondone 1').format(argstr)]
+    def _call(self, argstr, need_stderr=False, n_threads=None, dry_run=False):
+        cmd = [
+            self.docker_exe,
+            "run",
+            "-v",
+            f"{os.getcwd()}:/io{':z' if self.selinux else ''}",
+            self.image,
+            "/bin/bash",
+            "-c",
+            f"tclsh /usr/local/oommf/oommf/oommf.tcl boxsi +fg {argstr} -exitondone 1",
+        ]
         if n_threads is not None:
-            cmd += ['-threads', str(n_threads)]
-        return sp.run(cmd, stdout=sp.PIPE, stderr=sp.PIPE)
+            cmd += ["-threads", str(n_threads)]
+        if dry_run:
+            return cmd
+        else:
+            return sp.run(cmd, stdout=sp.PIPE, stderr=sp.PIPE)
 
-    def _kill(self, targets=('all',)):
+    def _kill(self, targets=("all",)):
         # There is no need to kill OOMMF when run inside docker.
         pass
 
     def errors(self):
-        msg = 'boxsi.errors cannot be retrieved from Docker container.'
+        msg = "boxsi.errors cannot be retrieved from Docker container."
         raise EnvironmentError(msg)
 
     def __repr__(self):
-        return (f'DockerOOMMFRunner(docker_exe={self.docker_exe}, '
-                f'image={self.image})')
+        return f"DockerOOMMFRunner(docker_exe={self.docker_exe}, image={self.image})"
 
 
 class Runner:
@@ -392,9 +346,9 @@ class Runner:
 
     def __init__(self):
         self.cache_runner = True
-        self.envvar = 'OOMMFTCL'
-        self.oommf_exe = 'oommf'
-        self.docker_exe = 'docker'
+        self.envvar = "OOMMFTCL"
+        self.oommf_exe = "oommf"
+        self.docker_exe = "docker"
         self._runner = None
 
     @property
@@ -432,7 +386,7 @@ class Runner:
 
         """
         if self.cache_runner and self._runner is not None:
-            log.debug('Returning cached runner.')
+            log.debug("Returning cached runner.")
             return self._runner
         self.autoselect_runner()
         return self._runner
@@ -440,7 +394,7 @@ class Runner:
     @runner.setter
     def runner(self, runner):
         if runner.status != 0:
-            raise ValueError(f'{runner=} cannot be used.')
+            raise ValueError(f"{runner=} cannot be used.")
         self._runner = runner
 
     def autoselect_runner(self):
@@ -472,55 +426,66 @@ class Runner:
 
         """
         log.debug(
-            'Starting autoselect_runner: cache_runner=%(cache_runner)s, '
-            'envvar=%(envvar)s, oommf_exe=%(oommf_exe)s, '
-            'docker_exe=%(docker_exe)s)', {
-                'cache_runner': self.cache_runner,
-                'envvar': self.envvar,
-                'oommf_exe': self.oommf_exe,
-                'docker_exe': self.docker_exe
-            })
+            "Starting autoselect_runner: cache_runner=%(cache_runner)s, "
+            "envvar=%(envvar)s, oommf_exe=%(oommf_exe)s, "
+            "docker_exe=%(docker_exe)s)",
+            {
+                "cache_runner": self.cache_runner,
+                "envvar": self.envvar,
+                "oommf_exe": self.oommf_exe,
+                "docker_exe": self.docker_exe,
+            },
+        )
 
         # Check for the OOMMFTCL environment variable pointing to oommf.tcl.
         log.debug(
-            'Step 1: Checking for the self.envvar=%(envvar)s environment'
-            ' variable pointing to oommf.tcl.', {'envvar': self.envvar})
+            "Step 1: Checking for the self.envvar=%(envvar)s environment"
+            " variable pointing to oommf.tcl.",
+            {"envvar": self.envvar},
+        )
         oommf_tcl = os.environ.get(self.envvar, None)
         if oommf_tcl is not None:
-            cmd = [
-                'tclsh', oommf_tcl, 'boxsi', '+fg', '+version', '-exitondone',
-                '1'
-            ]
+            cmd = ["tclsh", oommf_tcl, "boxsi", "+fg", "+version", "-exitondone", "1"]
             try:
                 res = sp.run(cmd, stdout=sp.PIPE, stderr=sp.PIPE)
             except FileNotFoundError:
-                log.warning('oommf.tcl was not found.')
+                log.warning("oommf.tcl was not found.")
             else:
                 if res.returncode:
                     log.warning(
-                        'OOMMFTCL is set, but OOMMF could not be run.\n'
-                        'stdout:\n%(stdout)s\nstderr:\n%(stderr)s', {
-                            'stdout': res.stdout,
-                            'stderr': res.stderr
-                        })
+                        "OOMMFTCL is set, but OOMMF could not be run.\n"
+                        "stdout:\n%(stdout)s\nstderr:\n%(stderr)s",
+                        {"stdout": res.stdout, "stderr": res.stderr},
+                    )
                 else:
                     self._runner = TclOOMMFRunner(oommf_tcl)
                     return
 
         # OOMMF available as an executable - in a conda env on Mac/Linux, or
         # oommf installed separately.
-        log.debug('Step 2: is oommf_exe=%(oommf_exe)s in PATH? '
-                  'Could be from conda env or manual install.',
-                  {'oommf_exe': self.oommf_exe})
+        log.debug(
+            "Step 2: is oommf_exe=%(oommf_exe)s in PATH? "
+            "Could be from conda env or manual install.",
+            {"oommf_exe": self.oommf_exe},
+        )
         oommf_exe = shutil.which(self.oommf_exe)
-        log.debug('Ouput from "which oommf_exe"=%(oommf_exe)s',
-                  {'oommf_exe': oommf_exe})
+        log.debug(
+            'Ouput from "which oommf_exe"=%(oommf_exe)s', {"oommf_exe": oommf_exe}
+        )
         if oommf_exe:
-            cmd = [oommf_exe, 'boxsi',
-                   '+fg', '+version', '-exitondone', '1', '-kill', 'all']
+            cmd = [
+                oommf_exe,
+                "boxsi",
+                "+fg",
+                "+version",
+                "-exitondone",
+                "1",
+                "-kill",
+                "all",
+            ]
 
             stdout = stderr = sp.PIPE
-            if sys.platform == 'win32':
+            if sys.platform == "win32":
                 stdout = stderr = None  # pragma: no cover
 
             log.debug("Attempt command call")  # DEBUG
@@ -531,41 +496,42 @@ class Runner:
                 self._runner = ExeOOMMFRunner(oommf_exe)
                 return
             else:
-                log.warning('oommf_exe=%(exe)s found but not executable.',
-                            {'exe': oommf_exe})
-                log.debug('exitcode = %(returncode)s',
-                          {'returncode': res.returncode})
+                log.warning(
+                    "oommf_exe=%(exe)s found but not executable.", {"exe": oommf_exe}
+                )
+                log.debug("exitcode = %(returncode)s", {"returncode": res.returncode})
                 if res.returncode == 127:  # maybe oommf is a pyenv shim?
                     pass
 
         # Check for docker to run OOMMF in a docker image.
-        log.debug("Step 3: Can we use docker to host OOMMF?"
-                  ' ("docker_exe=%(docker_exe)s")',
-                  {'docker_exe': self.docker_exe})
-        cmd = [self.docker_exe, 'images']
+        log.debug(
+            'Step 3: Can we use docker to host OOMMF? ("docker_exe=%(docker_exe)s")',
+            {"docker_exe": self.docker_exe},
+        )
+        cmd = [self.docker_exe, "images"]
         try:
             res = sp.run(cmd, stdout=sp.PIPE, stderr=sp.PIPE)
         except FileNotFoundError:
-            log.warning('Docker was not found.')
+            log.warning("Docker was not found.")
         else:
             if res.returncode != 0:
-                log.warning('Error running docker\nstdout:\n%(stdout)s\n'
-                            'stderr:\n%(stderr)s',
-                            {'stdout': res.stdout, 'stderr': res.stderr})
+                log.warning(
+                    "Error running docker\nstdout:\n%(stdout)s\nstderr:\n%(stderr)s",
+                    {"stdout": res.stdout, "stderr": res.stderr},
+                )
             else:
                 self._runner = DockerOOMMFRunner(docker_exe=self.docker_exe)
                 return
 
         # If OOMMFRunner was not returned up to this point, we raise an
         # exception.
-        raise EnvironmentError('Cannot find OOMMF.')
+        raise EnvironmentError("Cannot find OOMMF.")
 
     def __repr__(self):
         # avoid selecting a runner when calling __repr__
         _runner = self._runner if self._runner is not None else "UNSET"
 
-        return (f'OOMMF runner: {_runner}\n'
-                f'runner is cached: {self.cache_runner}')
+        return f"OOMMF runner: {_runner}\nrunner is cached: {self.cache_runner}"
 
 
 def overhead():
@@ -590,23 +556,22 @@ def overhead():
     True
 
     """
-    # Running OOMMF through oommfc.
-    system = mm.examples.macrospin()
-    td = oc.TimeDriver()
-    oommfc_start = time.time()
-    td.drive(system, t=1e-12, n=1, save=True, overwrite=True)
-    oommfc_stop = time.time()
-    oommfc_time = oommfc_stop - oommfc_start
+    with tempfile.TemporaryDirectory() as workingdir:
+        with uu.changedir(workingdir):
+            # Running OOMMF through oommfc.
+            system = mm.examples.macrospin()
+            td = oc.TimeDriver()
+            oommfc_start = time.time()
+            td.drive(system, t=1e-12, n=1)
+            oommfc_stop = time.time()
+            oommfc_time = oommfc_stop - oommfc_start
 
-    # Running OOMMF directly.
-    oommf_runner = oc.runner.runner
-    mifpath = os.path.realpath(os.path.join(system.name,
-                                            'drive-0',
-                                            'macrospin.mif'))
-    oommf_start = time.time()
-    oommf_runner.call(mifpath)
-    oommf_stop = time.time()
-    oommf_time = oommf_stop - oommf_start
-    oc.delete(system)
+            # Running OOMMF directly.
+            oommf_runner = oc.runner.runner
+            mifpath = pathlib.Path(f"{system.name}/drive-0/macrospin.mif").resolve()
+            oommf_start = time.time()
+            oommf_runner.call(str(mifpath))
+            oommf_stop = time.time()
+            oommf_time = oommf_stop - oommf_start
 
     return oommfc_time - oommf_time
