@@ -3,6 +3,11 @@ from .energy import energy_script
 from .evolver import evolver_script
 from .mesh import mesh_script
 from .system import system_script
-from .util import (box_atlas, file_vector_field, setup_m0,
-                   setup_scalar_parameter, setup_vector_parameter,
-                   vector_norm_scalar_field)
+from .util import (
+    box_atlas,
+    file_vector_field,
+    setup_m0,
+    setup_scalar_parameter,
+    setup_vector_parameter,
+    vector_norm_scalar_field,
+)
