@@ -3,6 +3,6 @@ import pytest
 import oommfc as oc
 
 
-@pytest.fixture(scope='module')
+@pytest.fixture(scope="module")
 def calculator():
     return oc
